@@ -6,11 +6,11 @@ mod service_holder;
 pub use beat_reactor::HeartBeatReactor;
 pub use service_holder::ServiceHolder;
 pub use security::AccessTokenHolder;
-use self::model::ServiceInfo;
+use self::model::Instance;
 
 use async_trait::async_trait;
 
 #[async_trait]
 pub trait ServiceChangeListener: Send + Sync {
-    async fn changed(&mut self, info: ServiceInfo);
+    async fn changed(&mut self, service_name: &str, hosts: Vec<Instance>);
 }
\ No newline at end of file
