@@ -20,7 +20,7 @@ mod test {
 
     use crate::{
         NamingClient, config::{NamingConfig, ServerConfig}, constants, 
-        error::Result, model::ServiceInfo, ServiceChangeListener
+        error::Result, model::Instance, ServiceChangeListener
     };
 
     fn init_logger() {
@@ -65,8 +65,8 @@ mod test {
 
     #[async_trait]
     impl ServiceChangeListener for Listener {
-        async fn changed(&mut self, info: ServiceInfo) {
-            println!("changed => {:?}", info);
+        async fn changed(&mut self, service_name: &str, hosts: Vec<Instance>) {
+            println!("changed => {}:{:?}", service_name, hosts);
         }
     }
 
